Stan Math Library: stan/math/prim/arr/fun/scaled_add.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
scaled_add.hpp File Reference
`#include <vector>`
`#include <cstddef>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
void | stan::math::scaled_add (std::vector< double > &x, const std::vector< double > &y, const double lambda)

[ Stan Home Page ] © 2011–2016, Stan Development Team.